proveZkEmail method
Generates a zkEmail proof.
Takes the path to the Serialized Rekeying Set (SRS) file and the inputs map. The inputs map structure should match the one expected by the native mopro library, derived from the zkemail_input.json structure.
Implementation
Future<ProveZkEmailResult> proveZkEmail(String srsPath, Map<String, List<String>> inputs) {
throw UnimplementedError('proveZkEmail() has not been implemented.');
}